%global python3_pkgversion 3.11
%global pypi_name SecretStorage
%global srcname secretstorage
%global pypi_version 3.3.3


Name:           python-%{srcname}
Version:        %{pypi_version}
Release:        1%{?dist}
Summary:        Python bindings to FreeDesktop.org Secret Service API

# Check if the automatically generated License and its spelling is correct for Fedora
# https://docs.fedoraproject.org/en-US/packaging-guidelines/LicensingGuidelines/
License:        BSD-3-Clause
URL:            https://github.com/mitya57/secretstorage
Source:         %{pypi_source %pypi_name}

BuildArch:      noarch

BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-rpm-macros
BuildRequires:  python%{python3_pkgversion}-pip
BuildRequires:  python%{python3_pkgversion}-pytest
BuildRequires:  python%{python3_pkgversion}-setuptools >= 30.3
BuildRequires:  python%{python3_pkgversion}-wheel
BuildRequires:  python%{python3_pkgversion}-jeepney >= 0.6
BuildRequires:  python%{python3_pkgversion}-cryptography >= 2.0
BuildRequires:  pyproject-rpm-macros
BuildRequires:  gnome-keyring
BuildRequires:  dbus-daemon


# Fill in the actual package description to submit package to Fedora
%global _description %{expand:
This module provides a way for securely storing passwords and other secrets.
It uses D-Bus Secret Service API that is supported by GNOME Keyring, KWallet (since version 5.97) and KeePassXC.
The main classes provided are secretstorage.Item, representing a secret item (that has a label, a secret and some attributes) and secretstorage.Collection, a place items are stored in.
SecretStorage supports most of the functions provided by Secret Service, including creating and deleting items and collections, editing items, locking and unlocking collections (asynchronous unlocking is also supported).
The documentation can be found on secretstorage.readthedocs.io.}

%description %_description

%package -n     python%{python3_pkgversion}-%{srcname}
Summary:        %{summary}
Requires:       python%{python3_pkgversion}-cryptography >= 2.0
Requires:       python%{python3_pkgversion}-jeepney >= 0.6  

%description -n python%{python3_pkgversion}-%{srcname} %_description


%prep
%autosetup -p1 -n %{pypi_name}-%{version}

%build
%pyproject_wheel


%install
%pyproject_install
# For official Fedora packages, including files with '*' +auto is not allowed
# Replace it with a list of relevant Python modules/globs and list extra files in %%files
%pyproject_save_files '*' +auto


%check
dbus-run-session -- bash -c "%{pytest}"

%files -n python%{python3_pkgversion}-%{srcname} -f %{pyproject_files}
%doc README.rst
%license LICENSE
%{python3_sitelib}/%{srcname}
%{python3_sitelib}/%{pypi_name}-%{pypi_version}.dist-info


%changelog
* Mon Feb 24 2025 Carlos Heiras <carlos.heiras@oracle.com> - 3.3.3-1
- Initial release
